==> geoffwilliams-r_profile-1.8.0.tar.gz: geoffwilliams-r_profile-1.8.0/spec/classes/virtual/vagrant_spec.rb <==
require 'spec_helper'
require 'puppet_factset'
describe 'r_profile::virtual::vagrant' do
  # Uncomment only the factset you would like to use for these tests
  # system_name = 'AIX-6.1-powerpc'
  # system_name = 'AIX-7.1-powerpc'
  # system_name = 'CentOS-5.11-32'
  # system_name = 'CentOS-5.11-64'
  # system_name = 'CentOS-6.6-32'
  # system_name = 'CentOS-6.6-64'
  system_name = 'CentOS-7.0-64'
  # system_name = 'Debian-6.0.10-32'
  # system_name = 'Debian-6.0.10-64'
  # system_name = 'Debian-7.8-32'
  # system_name = 'Debian-7.8-64'
  # system_name = 'SLES-11.3-64'
  # system_name = 'SLES-12.1-64'
  # system_name = 'Ubuntu-12.04-32'
  # system_name = 'Ubuntu-12.04-64'
  # system_name = 'Ubuntu-14.04-32'
  # system_name = 'Ubuntu-14.04-64'
  # system_name = 'Windows_Server-2008r2-64'
  # system_name = 'Windows_Server-2012r2-64'
  # system_name = 'solaris-10_u9-sparc-64'
  # system_name = 'solaris-11.2-sparc-64'
  let :facts do
    PuppetFactset::factset_hash(system_name)
  end

  let :params do
    {
      :vms => {
        "demo1" => {
          "ip" => "192.168.33.33",

        },
        "demo2" => {
          "ip" => "192.168.33.66",
        }
      },
      :vm_default => {
        "ensure"        => "running",
        "box"           => "bento/centos-7.3",
        "memory"        => "512",
        "cpu"           => "1",
        "puppet_master" => "192.168.1.50",
      }
    }
  end

  context 'compiles ok' do
    it { should compile }
  end

  context 'with default values for all parameters' do
    it { should contain_class('r_profile::virtual::vagrant') }
  end
end

==> geoffwilliams-r_profile-1.15.0.tar.gz: geoffwilliams-r_profile-1.15.0/spec/classes/virtual/vagrant_spec.rb <==
require 'spec_helper'
require 'puppet_factset'
describe 'r_profile::virtual::vagrant' do
  # Uncomment only the factset you would like to use for these tests
  # system_name = 'AIX-6.1-powerpc'
  # system_name = 'AIX-7.1-powerpc'
  # system_name = 'CentOS-5.11-32'
  # system_name = 'CentOS-5.11-64'
  # system_name = 'CentOS-6.6-32'
  # system_name = 'CentOS-6.6-64'
  system_name = 'CentOS-7.0-64'
  # system_name = 'Debian-6.0.10-32'
  # system_name = 'Debian-6.0.10-64'
  # system_name = 'Debian-7.8-32'
  # system_name = 'Debian-7.8-64'
  # system_name = 'SLES-11.3-64'
  # system_name = 'SLES-12.1-64'
  # system_name = 'Ubuntu-12.04-32'
  # system_name = 'Ubuntu-12.04-64'
  # system_name = 'Ubuntu-14.04-32'
  # system_name = 'Ubuntu-14.04-64'
  # system_name = 'Windows_Server-2008r2-64'
  # system_name = 'Windows_Server-2012r2-64'
  # system_name = 'solaris-10_u9-sparc-64'
  # system_name = 'solaris-11.2-sparc-64'
  let :facts do
    PuppetFactset::factset_hash(system_name)
  end

  let :params do
    {
      :vms => {
        "demo1" => {
          "ip" => "192.168.33.33",

        },
        "demo2" => {
          "ip" => "192.168.33.66",
        }
      },
      :vm_default => {
        "ensure"           => "running",
        "box"              => "bento/centos-7.3",
        "memory"           => "512",
        "cpu"              => "1",
        "puppet_master_ip" => "192.168.1.50",
      }
    }
  end

  context 'compiles ok' do
    it { should compile }
  end

  context 'with default values for all parameters' do
    it { should contain_class('r_profile::virtual::vagrant') }
  end
end
